@@ -1,11 +1,11 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
 ## Database Object Interface - ~/lib/DB/Object/SQLite/Query.pm
-## Version v0.3.8
-## Copyright(c) 2019 DEGUEST Pte. Ltd.
+## Version v0.3.9
+## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/06/16
-## Modified 2021/08/18
+## Modified 2023/02/24
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -18,7 +18,7 @@ BEGIN
     use warnings;
     use parent qw( DB::Object::Query );
     use vars qw( $VERSION $DEBUG $VERBOSE );
-    $VERSION = 'v0.3.8';
+    $VERSION = 'v0.3.9';
     $DEBUG = 0;
     $VERBOSE = 0;
 };
@@ -73,16 +73,37 @@ sub format_to_epoch
 # sub having { return( shift->_having( @_ ) ); }
 sub having { return( shift->_where_having( 'having', 'having', @_ ) ); }
 
-# https://sqlite.org/limits.html
+# <https://sqlite.org/lang_select.html#limitoffset>
+# <https://sqlite.org/lang_delete.html>
+# <https://sqlite.org/lang_update.html>
 sub limit
 {
     my $self  = shift( @_ );
     my $limit = $self->_process_limit( @_ );
     if( CORE::length( $limit->metadata->limit ) )
     {
-        $limit->generic( CORE::length( $limit->metadata->offset ) ? ' LIMIT ? OFFSET ?' : 'LIMIT ?' );
-        $limit->value( CORE::length( $limit->metadata->offset ) ? CORE::sprintf( 'LIMIT %d OFFSET %d', $limit->metadata->limit, $limit->metadata->offset ) : CORE::sprintf( 'LIMIT %d', $limit->metadata->limit ) );
-                                                                                                                                                                                                                                                                                                                                                                            }
+        $limit->generic( CORE::length( $limit->metadata->offset ) ? 'LIMIT ? OFFSET ?' : 'LIMIT ?' );
+        # User is managing the binding of value
+        if( (
+                $limit->metadata->offset eq '?' &&
+                $limit->metadata->limit eq '?'
+            ) || $limit->metadata->limit eq '?' )
+        {
+            $limit->value(
+                CORE::length( $limit->metadata->offset )
+                ?  'LIMIT ? OFFSET ?'
+                : 'LIMIT ?'
+            );
+        }
+        else
+        { 
+            $limit->value(
+                CORE::length( $limit->metadata->offset )
+                ? CORE::sprintf( 'LIMIT %d OFFSET %d', $limit->metadata->limit, $limit->metadata->offset )
+                : CORE::sprintf( 'LIMIT %d', $limit->metadata->limit )
+            );
+        }
+    }
     return( $limit );
 }
 
@@ -351,7 +372,7 @@ sub _query_components
 }
 
 1;
-
+# NOTE: POD
 __END__
 
 =encoding utf-8
@@ -366,7 +387,7 @@ DB::Object::SQLite::Query - SQLite Query Object
 
 =head1 VERSION
 
-    v0.3.8
+    v0.3.9
 
 =head1 DESCRIPTION
 
